Page 80 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 80

Home

    been used with great success by other subversive
    organizations throughout the the 20th century.
    William P. Hoar had this to say about the early

    The young and independent Republic of the United
    States had survived subversion by a European conspiracy
    and now had breathing space in which to recuperate. The
    disease, however, had not been conquered and would
    appear again.

    destiny and survived to become the world's greatest
    example of what men can accomplish when free from the
    life-choking restraints of Socialism. By the beginning of
    the the century, the United States was one of the
    wealthiest and most powerful nations on earth.

    nm

    Religious freedom enabled Americans to build more
    churches, establish more schools, publish more Bibles,
    and send more missionaries than any other country had

    American greatness continued right up to the
    beginning of the 20th century when more and more
    people began to forget the warnings expressed by men
    like William Cullen Bryant, "Not yet, O freedom! Close
    thy lids in slumber, for thine enemy never sleeps."

    75

    Attempts to Divide America

    internal attacks against America:

    In spite of tremendous odds, America fulfilled her

    yet been able to do.